Denoising Basics with Aydin.
============================

.. raw:: html

   <iframe src="https://docs.google.com/document/d/e/2PACX-1vRl0XA6-9Fc4XiuoiNBoMKzmEfmaHxhilK7xwA2FWNJSDlXLkdLHPP0xXkqSUv4VKXJfPPU-iqDAZso/pub?embedded=true" height="11380" width="720"></iframe>
